==> mleap-runtime_2.11-0.4.0-sources.jar: ml/combust/mleap/bundle/ops/feature/HashingTermFrequencyOp.scala <==
package ml.combust.mleap.bundle.ops.feature

import ml.combust.bundle.BundleContext
import ml.combust.bundle.dsl._
import ml.combust.bundle.op.{OpModel, OpNode}
import ml.combust.mleap.core.feature.HashingTermFrequencyModel
import ml.combust.mleap.runtime.MleapContext
import ml.combust.mleap.runtime.transformer.feature.HashingTermFrequency

/**
  * Created by hollinwilkins on 10/30/16.
  */
class HashingTermFrequencyOp extends OpNode[MleapContext, HashingTermFrequency, HashingTermFrequencyModel] {
  override val Model: OpModel[MleapContext, HashingTermFrequencyModel] = new OpModel[MleapContext, HashingTermFrequencyModel] {
    override val klazz: Class[HashingTermFrequencyModel] = classOf[HashingTermFrequencyModel]

    override def opName: String = Bundle.BuiltinOps.feature.hashing_term_frequency

    override def store(model: Model, obj: HashingTermFrequencyModel)
                      (implicit context: BundleContext[MleapContext]): Model = {
      model.withAttr("num_features", Value.long(obj.numFeatures))
    }

    override def load(model: Model)
                     (implicit context: BundleContext[MleapContext]): HashingTermFrequencyModel = {
      HashingTermFrequencyModel(numFeatures = model.value("num_features").getLong.toInt)
    }
  }

  override val klazz: Class[HashingTermFrequency] = classOf[HashingTermFrequency]

  override def name(node: HashingTermFrequency): String = node.uid

  override def model(node: HashingTermFrequency): HashingTermFrequencyModel = node.model

  override def load(node: Node, model: HashingTermFrequencyModel)
                   (implicit context: BundleContext[MleapContext]): HashingTermFrequency = {
    HashingTermFrequency(uid = node.name,
      inputCol = node.shape.standardInput.name,
      outputCol = node.shape.standardOutput.name,
      model = model)
  }

  override def shape(node: HashingTermFrequency): Shape = Shape().withStandardIO(node.inputCol, node.outputCol)
}

==> mleap-runtime_2.12-0.17.0-sources.jar: ml/combust/mleap/bundle/ops/feature/HashingTermFrequencyOp.scala <==
package ml.combust.mleap.bundle.ops.feature

import ml.combust.bundle.BundleContext
import ml.combust.bundle.dsl._
import ml.combust.bundle.op.OpModel
import ml.combust.mleap.bundle.ops.MleapOp
import ml.combust.mleap.core.feature.HashingTermFrequencyModel
import ml.combust.mleap.runtime.MleapContext
import ml.combust.mleap.runtime.transformer.feature.HashingTermFrequency

/**
  * Created by hollinwilkins on 10/30/16.
  */
class HashingTermFrequencyOp extends MleapOp[HashingTermFrequency, HashingTermFrequencyModel] {
  override val Model: OpModel[MleapContext, HashingTermFrequencyModel] = new OpModel[MleapContext, HashingTermFrequencyModel] {
    override val klazz: Class[HashingTermFrequencyModel] = classOf[HashingTermFrequencyModel]

    override def opName: String = Bundle.BuiltinOps.feature.hashing_term_frequency

    override def store(model: Model, obj: HashingTermFrequencyModel)
                      (implicit context: BundleContext[MleapContext]): Model = {
      model.withValue("num_features", Value.long(obj.numFeatures))
        .withValue("binary", Value.boolean(obj.binary))
    }

    override def load(model: Model)
                     (implicit context: BundleContext[MleapContext]): HashingTermFrequencyModel = {
      val binary = model.getValue("binary").map(_.getBoolean).getOrElse(false)
      HashingTermFrequencyModel(numFeatures = model.value("num_features").getLong.toInt, binary = binary)

    }
  }

  override def model(node: HashingTermFrequency): HashingTermFrequencyModel = node.model
}
